@@ -21,11 +21,16 @@
 
 #include <stddef.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 enum VmafPixelFormat {
     VMAF_PIX_FMT_UNKNOWN,
     VMAF_PIX_FMT_YUV420P,
     VMAF_PIX_FMT_YUV422P,
     VMAF_PIX_FMT_YUV444P,
+    VMAF_PIX_FMT_YUV400P,
 };
 
 typedef struct VmafRef VmafRef;
@@ -44,4 +49,8 @@ int vmaf_picture_alloc(VmafPicture *pic, enum VmafPixelFormat pix_fmt,
 
 int vmaf_picture_unref(VmafPicture *pic);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __VMAF_PICTURE_H__ */
