@@ -20,4 +20,5 @@ int compute_adm(const float *ref, const float *dis, int w, int h,
                 int ref_stride, int dis_stride, double *score,
                 double *score_num, double *score_den, double *scores,
                 double border_factor, double adm_enhn_gain_limit,
-                double adm_norm_view_dist, int adm_ref_display_height);
+                double adm_norm_view_dist, int adm_ref_display_height,
+                int adm_csf_mode);
