@@ -365,7 +365,8 @@ def check_program_exist(program):
 
     '''
     try:
-        subprocess.call(program.split(), stdout=open(os.devnull, 'wb'))
+        with open(os.devnull, "wb") as devnull_fd:
+            subprocess.call(program.split(), stdout=devnull_fd)
         return True
     except OSError as e:
         if e.errno == errno.ENOENT:
@@ -524,7 +525,7 @@ class MyTestCase(unittest.TestCase):
 class QualityRunnerTestMixin(object):
 
     def run_each(self, score, runner_class, asset, optional_dict,
-                 result_store=None, places=5):
+                 optional_dict2=None, result_store=None, places=5):
         runner = runner_class(
             [asset],
             None,
@@ -532,6 +533,7 @@ class QualityRunnerTestMixin(object):
             delete_workdir=True,
             result_store=result_store,
             optional_dict=optional_dict,
+            optional_dict2=optional_dict2,
         )
         runner.run(parallelize=False)
         results = runner.results
